Documentation
¶
Index ¶
- type CheckPinResponse
- type Client
- func (c *Client) CheckPin(check, authpin string) (CheckPinResponse, error)
- func (c *Client) DelayedLink(delayedID string) (DelayedResponse, error)
- func (c *Client) DeleteMagnet(id string) (DeleteMagnetResponse, error)
- func (c *Client) GetDomainsOnly() (Domains, error)
- func (c *Client) GetPin() (GetPinResponse, error)
- func (c *Client) GetUserInfo() (User, error)
- func (c *Client) InstantAvailability(magnets []string) (InstantAvailabilityResponse, error)
- func (c *Client) RestartMagnet(id string) (RestartMagnetResponse, error)
- func (c *Client) SetAPIKey(apikey string) error
- func (c *Client) StatusMagnet(id string) (StatusMagnetResponse, error)
- func (c *Client) StreamingLink(stream, id string) (StreamingResponse, error)
- func (c *Client) UnlockLink(link string) (UnlockLinkResponse, error)
- func (c *Client) UploadMagnet(magnets []string) (MagnetsUploadResponse, error)
- type DelayedResponse
- type DeleteMagnetResponse
- type Domains
- type GetPinResponse
- type InstantAvailabilityResponse
- type MagnetsUploadResponse
- type RestartMagnetResponse
- type StatusMagnetResponse
- type StreamingResponse
- type UnlockLinkResponse
- type User
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CheckPinResponse ¶
type CheckPinResponse struct {
Status string `json:"status"`
Data checkPinResponseData `json:"data,omitempty"`
Error alldebridError `json:"error,omitempty"`
}
CheckPinResponse contains data about the check pin request
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client is the base AllDebrid client
func (*Client) CheckPin ¶
func (c *Client) CheckPin(check, authpin string) (CheckPinResponse, error)
CheckPin gives you an apikey after pin validating
func (*Client) DelayedLink ¶
func (c *Client) DelayedLink(delayedID string) (DelayedResponse, error)
DelayedLink returns a downloadable link for the given delayed id
func (*Client) DeleteMagnet ¶
func (c *Client) DeleteMagnet(id string) (DeleteMagnetResponse, error)
DeleteMagnet removes a download from alldebrid
func (*Client) GetDomainsOnly ¶
GetDomainsOnly returns list of supported hosts domains and redirectors
func (*Client) GetPin ¶
func (c *Client) GetPin() (GetPinResponse, error)
GetPin asks Alldebrid for a new pin
func (*Client) GetUserInfo ¶
GetUserInfo retrieves user infos from alldebrid
func (*Client) InstantAvailability ¶
func (c *Client) InstantAvailability(magnets []string) (InstantAvailabilityResponse, error)
InstantAvailability sends magnet(s) to AllDebrid to know if thery are already available
func (*Client) RestartMagnet ¶
func (c *Client) RestartMagnet(id string) (RestartMagnetResponse, error)
RestartMagnet will restart a failed torrent
func (*Client) SetAPIKey ¶
SetAPIKey sets the client apikey (in case you obtained it via pin request)
func (*Client) StatusMagnet ¶
func (c *Client) StatusMagnet(id string) (StatusMagnetResponse, error)
StatusMagnet returns the status of an Alldebrid download
func (*Client) StreamingLink ¶
func (c *Client) StreamingLink(stream, id string) (StreamingResponse, error)
StreamingLink returns a delayed id or the direct link
func (*Client) UnlockLink ¶
func (c *Client) UnlockLink(link string) (UnlockLinkResponse, error)
UnlockLink returns a downloadable link
func (*Client) UploadMagnet ¶
func (c *Client) UploadMagnet(magnets []string) (MagnetsUploadResponse, error)
UploadMagnet sends magnet(s) to AllDebrid
type DelayedResponse ¶
type DelayedResponse struct {
Status string `json:"status"`
Data delayedResponseData `json:"data,omitempty"`
Error alldebridError `json:"error,omitempty"`
}
DelayedResponse is the response of the delayed call
type DeleteMagnetResponse ¶
type DeleteMagnetResponse struct {
Status string `json:"status"`
Data magnetResponseData `json:"data,omitempty"`
Error alldebridError `json:"error,omitempty"`
}
DeleteMagnetResponse is the response of the delete call
type Domains ¶
type Domains struct {
Status string `json:"status"`
Data domainsData `json:"data,omitempty"`
Error alldebridError `json:"error,omitempty"`
}
Domains is the domains response struct
type GetPinResponse ¶
type GetPinResponse struct {
Status string `json:"status"`
Data getPinData `json:"data,omitempty"`
Error alldebridError `json:"error,omitempty"`
}
GetPinResponse contains data about the get pin request
type InstantAvailabilityResponse ¶
type InstantAvailabilityResponse struct {
Status string `json:"status"`
Data instantAvailabilityResponseData `json:"data,omitempty"`
Error alldebridError `json:"error,omitempty"`
}
InstantAvailabilityResponse is the response of the instant availability call
type MagnetsUploadResponse ¶
type MagnetsUploadResponse struct {
Status string `json:"status"`
Data magnetsUploadResponseData `json:"data,omitempty"`
Error alldebridError `json:"error,omitempty"`
}
MagnetsUploadResponse is the response of the upload call
type RestartMagnetResponse ¶
type RestartMagnetResponse struct {
Status string `json:"status"`
Data magnetResponseData `json:"data,omitempty"`
Error alldebridError `json:"error,omitempty"`
}
RestartMagnetResponse is the response of the restart call
type StatusMagnetResponse ¶
type StatusMagnetResponse struct {
Status string `json:"status"`
Data statusMagnetResponseData `json:"data,omitempty"`
Error alldebridError `json:"error,omitempty"`
}
StatusMagnetResponse is the response of the status call
type StreamingResponse ¶
type StreamingResponse struct {
Status string `json:"status"`
Data streamingResponseData `json:"data,omitempty"`
Error alldebridError `json:"error,omitempty"`
}
StreamingResponse is the response of the streaming call
type UnlockLinkResponse ¶
type UnlockLinkResponse struct {
Status string `json:"status"`
Data unlockLinkResponseData `json:"data,omitempty"`
Error alldebridError `json:"error,omitempty"`
}
UnlockLinkResponse is the response of the unlock link call